@@ -467,7 +467,8 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
             items = [item[:item.find('|')] for item in field.getObject().getFgVocabulary()]
             filtered_items = [item for item in items if check_float(item)]
             if items != filtered_items or len(items) == len(filtered_items) == 0:
-                selection_fields.remove(field)
+#                selection_fields.remove(field)
+                selection_fields = [sf for sf in selection_fields if sf.id != field.id]
         selection_fields = [(brain.getObject().UID(), brain.Title) for brain in selection_fields]
         fields = fixed_point_fields + selection_fields
         for field in fields:
